Proximal Operators (`sigpy.prox`)
=================================

.. automodule::
   sigpy.prox

The Proximal Operator Class
---------------------------
.. autosummary::
   :toctree: generated
   :nosignatures:

   sigpy.prox.Prox

Prox Manipulation
-----------------
.. autosummary::
   :toctree: generated
   :nosignatures:

   sigpy.prox.Conj
   sigpy.prox.Stack
   sigpy.prox.UnitaryTransform

Basic Proxs
-----------
.. autosummary::
   :toctree: generated
   :nosignatures:

   sigpy.prox.NoOp
   sigpy.prox.BoxConstraint
   sigpy.prox.L1Proj
   sigpy.prox.L1Reg
   sigpy.prox.L2Proj
   sigpy.prox.L2Reg
   sigpy.prox.LInfProj
   sigpy.prox.PsdProj
